Enumeration
QmiLocAltitudeUncertainty
since: 1.37
Members
-
QMI_LOC_ALTITUDE_UNCERTAINTY_UNKNOWN -
Unknown.
- Value:
0 - Available since: 1.37
- Value:
-
QMI_LOC_ALTITUDE_UNCERTAINTY_POINT -
Uncertainty is valid at the injected horizontal position coordinates only.
- Value:
1 - Available since: 1.37
- Value:
-
QMI_LOC_ALTITUDE_UNCERTAINTY_FULL -
Uncertainty applies to the position of the device regardless of horizontal position.
- Value:
2 - Available since: 1.37
- Value:
Type functions
qmi_loc_altitude_uncertainty_get_string
Gets the nickname string for the QmiLocAltitudeUncertainty specified at val.
since: 1.37